This folder contains the code specifically for the project paper.

Including code to run the conspiracies pipeline directly on the data.

## Data locations
Data is located either on the Grundvig server on
```
/grundvig/data/Conspiracies/
```
or on Ucloud in the project `pandemic-info-resp` within the folder:
```
/conspiracies/data
```
Information on retrivial and location of tweets can be found in ``paper/docs/data-documentation.md``.

# API Keys
API keys are stored on Ucloud in the project `pandemic-info-resp` within the folder:
```
/conspiracies/*_api_key.txt
```
